==> cutefish-filemanager-0.4-2.src.tar.gz: filemanager-0.4/translations/bg_BG.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>CreateFolderDialog</name>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="28"/>
        <source>New folder name</source>
        <translation>Име на нова папка</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="55"/>
        <source>New folder</source>
        <translation>Нова папка</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>Отмени</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="85"/>
        <source>OK</source>
        <translation>Да</translation>
    </message>
</context>
<context>
    <name>DateHelper</name>
    <message>
        <location filename="../helper/datehelper.cpp" line="15"/>
        <source>Now</source>
        <translation>Сега</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="17"/>
        <source>1 minute ago</source>
        <translation>преди 1 минута</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="19"/>
        <source>%1 minutes ago</source>
        <translation>%1 минути преди</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="23"/>
        <source>1 hour ago</source>
        <translation>преди 1 час</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="25"/>
        <source>%1 hours ago</source>
        <translation>преди %1 часа</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="29"/>
        <source>1 day ago</source>
        <translation>преди 1 ден</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="31"/>
        <source>%1 days ago</source>
        <translation>преди %1 дни</translation>
    </message>
</context>
<context>
    <name>DesktopView</name>
    <message>
        <location filename="../desktop/desktopview.cpp" line="44"/>
        <source>Desktop</source>
        <translation>Работен плот</translation>
    </message>
</context>
<context>
    <name>EmptyTrashDialog</name>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="30"/>
        <source>File Manager</source>
        <translation>Файлов мениджър</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="60"/>
        <source>Do you want to permanently delete all files from the Trash?</source>
        <translation>Искате ли да изтриете окончателно всички файлове от кошчето?</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="69"/>
        <source>Cancel</source>
        <translation>Отмени</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="75"/>
        <source>Empty Trash</source>
        <translation>Празен кошчето</translation>
    </message>
</context>
<context>
    <name>FilePropertiesDialog</name>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="178"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="226"/>
        <source>%1 files</source>
        <translation>%1 файлове</translation>
    </message>
</context>
<context>
    <name>FolderModel</name>
    <message>
        <location filename="../model/foldermodel.cpp" line="168"/>
        <source>%1 item</source>
        <translation>%1 елемент</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="168"/>
        <source>%1 items</source>
        <translation>%1 елементи</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="892"/>
        <source>Select All</source>
        <translation>Избери всички</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1107"/>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1110"/>
        <source>Open with</source>
        <translation>Отворете с</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1113"/>
        <source>Cut</source>
        <translation>Изрежете</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1116"/>
        <source>Copy</source>
        <translation>Копирайте</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1119"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1122"/>
        <source>New Folder</source>
        <translation>Нова папка</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1125"/>
        <source>Move To Trash</source>
        <translation>Преместване в кошчето</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1128"/>
        <source>Empty Trash</source>
        <translation>Празен кошчето</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1131"/>
        <source>Delete</source>
        <translation>Изтрийте</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1134"/>
        <source>Rename</source>
        <translation>Преименувайте</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1137"/>
        <source>Open in Terminal</source>
        <translation>Отваряне в терминал</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1140"/>
        <source>Set as Wallpaper</source>
        <translation>Задаване като тапет</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1143"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1146"/>
        <source>Change background</source>
        <translation>Смяна на фона</translation>
    </message>
</context>
<context>
    <name>FolderPage</name>
    <message>
        <location filename="../qml/FolderPage.qml" line="117"/>
        <source>Empty folder</source>
        <translation>Празна папка</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="148"/>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="60"/>
        <location filename="../qml/FolderPage.qml" line="153"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="50"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="53"/>
        <source>New Folder</source>
        <translation>Нова папка</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="67"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="73"/>
        <source>Edit</source>
        <translation>Редактиране</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="76"/>
        <source>Select All</source>
        <translation>Изберете всички</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="82"/>
        <source>Help</source>
        <translation>Помощ</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="85"/>
        <source>About</source>
        <translation>За</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="215"/>
        <source>%1 item</source>
        <translation>%1 елемент</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="216"/>
        <source>%1 items</source>
        <translation>%1 елемента</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="222"/>
        <source>%1 selected</source>
        <translation>%1 избран</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="233"/>
        <source>Empty Trash</source>
        <translation>Празен кошчето</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="70"/>
        <source>No applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="136"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="145"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="154"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs/openwithdialog.cpp" line="32"/>
        <source>Open With</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsMenu</name>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="45"/>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="79"/>
        <source>List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="115"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="149"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="183"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlacesModel</name>
    <message>
        <location filename="../model/placesmodel.cpp" line="39"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="46"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="53"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="60"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="67"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="74"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="81"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="86"/>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="95"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="108"/>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="119"/>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="126"/>
        <source>Calculating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="130"/>
        <source>Created:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="143"/>
        <source>Modified:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="156"/>
        <source>Accessed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="178"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="184"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="35"/>
        <source>File Manager</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> cutefish-filemanager-0.8-2.src.tar.gz: filemanager-0.8/translations/bg_BG.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>CreateFolderDialog</name>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="28"/>
        <source>New folder name</source>
        <translation>Име на нова папка</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="55"/>
        <source>New folder</source>
        <translation>Нова папка</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>Отмени</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="85"/>
        <source>OK</source>
        <translation>Да</translation>
    </message>
</context>
<context>
    <name>DateHelper</name>
    <message>
        <location filename="../helper/datehelper.cpp" line="15"/>
        <source>Now</source>
        <translation>Сега</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="17"/>
        <source>1 minute ago</source>
        <translation>преди 1 минута</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="19"/>
        <source>%1 minutes ago</source>
        <translation>%1 минути преди</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="23"/>
        <source>1 hour ago</source>
        <translation>преди 1 час</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="25"/>
        <source>%1 hours ago</source>
        <translation>преди %1 часа</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="29"/>
        <source>1 day ago</source>
        <translation>преди 1 ден</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="31"/>
        <source>%1 days ago</source>
        <translation>преди %1 дни</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="47"/>
        <source>Do you want to delete it permanently?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="56"/>
        <source>Cancel</source>
        <translation type="unfinished">Отмени</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="62"/>
        <source>Delete</source>
        <translation type="unfinished">Изтрийте</translation>
    </message>
</context>
<context>
    <name>DesktopView</name>
    <message>
        <location filename="../desktop/desktopview.cpp" line="44"/>
        <source>Desktop</source>
        <translation>Работен плот</translation>
    </message>
</context>
<context>
    <name>EmptyTrashDialog</name>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="30"/>
        <source>File Manager</source>
        <translation>Файлов мениджър</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="60"/>
        <source>Do you want to permanently delete all files from the Trash?</source>
        <translation>Искате ли да изтриете окончателно всички файлове от кошчето?</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="69"/>
        <source>Cancel</source>
        <translation>Отмени</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="75"/>
        <source>Empty Trash</source>
        <translation>Празен кошчето</translation>
    </message>
</context>
<context>
    <name>FilePropertiesDialog</name>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="179"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="227"/>
        <source>%1 files</source>
        <translation>%1 файлове</translation>
    </message>
</context>
<context>
    <name>FolderModel</name>
    <message>
        <location filename="../model/foldermodel.cpp" line="184"/>
        <source>%1 item</source>
        <translation>%1 елемент</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="184"/>
        <source>%1 items</source>
        <translation>%1 елементи</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="249"/>
        <source>The file or folder %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="981"/>
        <source>Select All</source>
        <translation>Избери всички</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1088"/>
        <source>File Manager</source>
        <translation type="unfinished">Файлов мениджър</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1281"/>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1284"/>
        <source>Open with</source>
        <translation>Отворете с</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1287"/>
        <source>Cut</source>
        <translation>Изрежете</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1290"/>
        <source>Copy</source>
        <translation>Копирайте</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1293"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1296"/>
        <source>New Folder</source>
        <translation>Нова папка</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1299"/>
        <source>Move To Trash</source>
        <translation>Преместване в кошчето</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1302"/>
        <source>Empty Trash</source>
        <translation>Празен кошчето</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1305"/>
        <source>Delete</source>
        <translation>Изтрийте</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1308"/>
        <source>Rename</source>
        <translation>Преименувайте</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1311"/>
        <source>Open in Terminal</source>
        <translation>Отваряне в терминал</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1314"/>
        <source>Set as Wallpaper</source>
        <translation>Задаване като тапет</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1317"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1320"/>
        <source>Change background</source>
        <translation>Смяна на фона</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1323"/>
        <source>Restore</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderPage</name>
    <message>
        <location filename="../qml/FolderPage.qml" line="134"/>
        <source>Empty folder</source>
        <translation>Празна папка</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="174"/>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="60"/>
        <location filename="../qml/FolderPage.qml" line="179"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="50"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="53"/>
        <source>New Folder</source>
        <translation>Нова папка</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="67"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="73"/>
        <source>Edit</source>
        <translation>Редактиране</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="76"/>
        <source>Select All</source>
        <translation>Изберете всички</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="83"/>
        <source>Cut</source>
        <translation type="unfinished">Изрежете</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="88"/>
        <source>Copy</source>
        <translation type="unfinished">Копирайте</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="93"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="99"/>
        <source>Help</source>
        <translation>Помощ</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="102"/>
        <source>About</source>
        <translation>За</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="241"/>
        <source>%1 item</source>
        <translation>%1 елемент</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="242"/>
        <source>%1 items</source>
        <translation>%1 елемента</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="248"/>
        <source>%1 selected</source>
        <translation>%1 избран</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="259"/>
        <source>Empty Trash</source>
        <translation>Празен кошчето</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="78"/>
        <source>No applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="142"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="151"/>
        <source>Cancel</source>
        <translation type="unfinished">Отмени</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="160"/>
        <source>Open</source>
        <translation type="unfinished">Отвори</translation>
    </message>
    <message>
        <location filename="../dialogs/openwithdialog.cpp" line="32"/>
        <source>Open With</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsMenu</name>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="47"/>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="85"/>
        <source>List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="127"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="165"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="189"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="227"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlacesModel</name>
    <message>
        <location filename="../model/placesmodel.cpp" line="39"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="47"/>
        <source>Desktop</source>
        <translation type="unfinished">Работен плот</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="55"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="63"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="71"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="79"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="87"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="93"/>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="117"/>
        <location filename="../model/placesmodel.cpp" line="265"/>
        <source>Drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="94"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="107"/>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="118"/>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="125"/>
        <source>Calculating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="129"/>
        <source>Created:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="142"/>
        <source>Modified:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="155"/>
        <source>Accessed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="177"/>
        <source>Cancel</source>
        <translation type="unfinished">Отмени</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="183"/>
        <source>OK</source>
        <translation type="unfinished">Да</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="35"/>
        <source>File Manager</source>
        <translation type="unfinished">Файлов мениджър</translation>
    </message>
</context>
</TS>
